@@ -7,31 +7,35 @@
 #'
 #' @details \code{clear_repo} removes packages deployed into the destination repository,
 #' updates the PACKAGES and PACKAGES.gz files, and resets the build results within the
-#' GRANRepository object. \code{clear_temp_fils} clears
+#' GRANRepository object. \code{clear_temp_files} clears
 #' intermediate files from the library location used during building, the temporary
 #' repository, the package staging area, and the store of install- and check-results.
 #'
 #' @param repo GRANRepository - The repository to clean
 #' @param checkout logical - Should the checkouts of packages also be cleared.
 #' Generally this is not necessary (default: FALSE)
-#'
+#' @param logs logical - should the logs (check, install, and single package) be cleared (default: FALSE)
 #' @return The GRANRepository object, ready to be rebuilt.
+#' @note It is not advised to clear the logs in a direct call to \code{clear_temp_files}. use \code{clear_repo} instead.
 #' @author Gabriel Becker
 #' @rdname clear
 #' @export
-clear_temp_fils = function(repo, checkout = FALSE) {
-    dirs = c( "temporary library" = temp_lib(repo),
-              "temporary repo" = temp_repo(repo),
-              "install results" = install_result_dir(repo),
-              "check results" = check_result_dir(repo),
-              "staging area" = staging(repo),
-              "covr reports" = coverage_report_dir(repo),
-              "package docs" = pkg_doc_dir(repo),
-              "single pkglogs" = pkg_log_dir(repo))
-
-    res = mapply(.clearhelper, dirs, repo = list(repo), dirlab = names(dirs))
+clear_temp_files = function(repo, checkout = FALSE, logs = FALSE) {
+    dirs = c("temporary library" = temp_lib(repo),
+             "temporary repo" = temp_repo(repo),
+             "staging area" = staging(repo))
+    if(logs)
+        dirs = c(dirs, 
+                 "covr reports" = coverage_report_dir(repo),
+                 "package docs" = pkg_doc_dir(repo),
+                 "package install logs" = install_result_dir(repo),
+                 "package check logs" = check_result_dir(repo),
+                 "single package GRAN logs" = pkg_log_dir(repo))
     if(checkout)
-        res = c(res, .clearhelper(checkout_dir(repo), repo, "checkout directory"))
+        dirs = c(dirs,
+                 "checkout directory" = checkout_dir(repo))
+    
+    res = mapply(.clearhelper, dirs, repo = list(repo), dirlab = names(dirs))
     if(!all(res))
         warning("Not all clearing steps succeeded. See the relevant GRAN log for more information")
     repo
@@ -58,7 +62,7 @@ clear_temp_fils = function(repo, checkout = FALSE) {
 
 #' @rdname clear
 #' @param all logical - Should temporary artifacts from the build process also be cleared
-#' (via automatically calling clear_temp_fils). Defaults to TRUE
+#' (via automatically calling clear_temp_files). Defaults to TRUE
 #' @param archivedir character - Optional. A directory where build packages
 #' deployed to the repository will be archived. Package versions already in
 #' the archive will not be overwritten.
@@ -70,7 +74,7 @@ clear_repo = function(repo, all = TRUE, checkout = FALSE, archivedir = NA) {
             dir.create(archivedir)
     }
     if(all)
-        res = clear_temp_fils(repo = repo, checkout = checkout)
+        res = clear_temp_files(repo = repo, checkout = checkout)
     else
         res = logical()
     d = destination(repo)
@@ -81,7 +85,8 @@ clear_repo = function(repo, all = TRUE, checkout = FALSE, archivedir = NA) {
         file.copy(fils, archivedir, overwrite = FALSE)
     }
     res = .clearhelper(d, repo, "deployed packages")
-    write_PACKAGES(d)
+    ## this doesn't do anything???
+    ##write_PACKAGES(d)
     if(!res)
         warning("Failed to fully clear packages from deployed repository")
     repo = resetResults(repo)
