@@ -4,8 +4,9 @@ setMethod("makeRepo", "PkgManifest",
           function(x, cores = 1, build_pkgs = NULL,
                    scm_auth = list("bioconductor.org" =
                        c("readonly", "readonly")),
-                   ...
-                   ) {
+                   constrained_build = FALSE,
+                   ...) 
+          {
 
               vers = data.frame(name= manifest_df(x)$name,
                   version = NA, stringsAsFactors = FALSE)
@@ -14,6 +15,7 @@ setMethod("makeRepo", "PkgManifest",
 
               makeRepo(sessMan, cores = cores, scm_auth = scm_auth,
                        build_pkgs = build_pkgs,
+                       constrained_build = FALSE,
                        ...)
           })
 
@@ -25,12 +27,15 @@ setMethod("makeRepo", "SessionManifest",
           function(x, cores = 1, build_pkgs = NULL,
                    scm_auth = list("bioconductor.org" =
                        c("readonly", "readonly")),
-                   ...
-                   ) {
+                   constrained_build = FALSE,
+                   ...) 
+          {
 
               repo = GRANRepository(manifest = x, param = RepoBuildParam(...))
               makeRepo(repo, cores = cores, scm_auth = scm_auth,
-                       build_pkgs = build_pkgs, ...)
+                       build_pkgs = build_pkgs, 
+                       constrained_build = FALSE,
+                       ...)
           })
 
 
@@ -42,6 +47,7 @@ setMethod("makeRepo", "GRANRepository",
           function(x, cores = 1, build_pkgs = NULL,
                    scm_auth = list("bioconductor.org" =
                                        c("readonly", "readonly")),
+                   constrained_build = FALSE,
                    ...) {
     message(paste("Started makeRepo at", Sys.time()))
     if(!haveGit()) {
@@ -60,7 +66,7 @@ setMethod("makeRepo", "GRANRepository",
     if(!is.null(repo2) ) {
         res = repo_results(repo)
         res2 = repo_results(repo2)
-        if(any(!is.na(res$lastAttempt)) &&
+        if(any(!is.na(res$lastAttempt)) && any(!is.na(res2$lastAttempt)) && 
         (max(res$lastAttempt, na.rm=TRUE) < max(res2$lastAttempt, na.rm=TRUE))) {
             warning("Loading latest results from specified repository")
             repo = repo2
@@ -77,10 +83,14 @@ setMethod("makeRepo", "GRANRepository",
         repo_results(repo)$suspended <- manifest_df(repo)$name %in% suspended_pkgs(repo)
     }
 
+    message(paste("Checking for (and fixing) R version mismatch in packages installed to temp library", Sys.time()))
+    repo = checkAndFixLibLoc(repo)
 
     message(paste("Building", sum(getBuilding(repo)), "packages"))
     ##package, build thine self!
-    repo = GRANonGRAN(repo)
+    if (!constrained_build) {
+       repo = GRANonGRAN(repo)
+    }
     ##do checkouts
     message(paste("Starting makeSrcDirs", Sys.time()))
     message(paste("Building", sum(getBuilding(repo)), "packages"))
@@ -88,7 +98,9 @@ setMethod("makeRepo", "GRANRepository",
     ##add reverse dependencies to build list
     repo = addRevDeps(repo)
     ##do checkouts again to grab reverse deps
-    repo = makeSrcDirs(repo, cores = cores, scm_auth = scm_auth)
+    if (!constrained_build) {
+      repo = makeSrcDirs(repo, cores = cores, scm_auth = scm_auth)
+    }
     ##build temp repository
     message(paste("Starting buildBranchesInRepo", Sys.time()))
     message(paste("Building", sum(getBuilding(repo)), "packages"))
@@ -99,7 +111,7 @@ setMethod("makeRepo", "GRANRepository",
     ##test packges
     message(paste("Invoking package tests", Sys.time()))
     message(paste("Building", sum(getBuilding(repo)), "packages"))
-    repo = doPkgTests(repo, cores = cores)
+    repo = doPkgTests(repo, cores = cores, constrained_build)
     ##copy successfully built tarballs to final repository
     message(paste("starting migrateToFinalRepo", Sys.time()))
     message(paste("Built", sum(getBuilding(repo)), "packages"))
@@ -110,7 +122,7 @@ setMethod("makeRepo", "GRANRepository",
         makeWinBins(repo, cores = cores)
     }
 
-    finalizeRepo(repo)
+    finalizeRepo(repo, cores = cores)
     message(paste("Completed makeRepo at", Sys.time()))
     return(repo)
 })
@@ -122,7 +134,9 @@ setMethod("makeRepo", "character",
           function(x, cores = 1, build_pkgs = NULL,
                    scm_auth = list("bioconductor.org" =
                        c("readonly", "readonly")),
-                   ...) {
+                   constrained_build = FALSE,
+                   ...) 
+          {
 
               if(!grepl("^(http|git|.*repo\\.R)", x))
                   x2 = list.files(x, pattern = "repo\\.R", full.names = TRUE,
@@ -135,5 +149,7 @@ setMethod("makeRepo", "character",
                        "with the location",
                        x)
               makeRepo(repo, cores = cores, build_pkgs = build_pkgs,
-                       scm_auth = scm_auth, ...)
+                       scm_auth = scm_auth, 
+                       constrained_build = constrained_build,
+                       ...)
           })
