@@ -18,15 +18,22 @@ updateArchive <- function (repo, repodest = destination(repo),
 
   # Identify which packages are new vs which are old
   builtpkgs <- list.files(repodest, pattern = ext, full.names = FALSE)
+  if(!length(builtpkgs))
+    return(NULL)
   noextfiles <- gsub(ext, "", builtpkgs)
   pkgs <- sapply(strsplit(builtpkgs, "_", fixed = TRUE), "[", 1L)
   verstxt <- gsub("[a-zA-Z0-9\\.]*_", "", noextfiles)
   vers <- package_version(verstxt)
   df <- data.frame(file = builtpkgs, package = pkgs,
-                   version = vers, stringsAsFactors = FALSE)
-  df <- df[order(df$package, df$version, decreasing = TRUE), ]
-  df$newest <- !duplicated(df$package)
-  df <- df[order(df$package, df$version, decreasing = FALSE), ]
+                   ##                 version = vers, stringsAsFactors = FALSE)
+                   ## we are using compareVersion which
+                   ## doesn't support package_version objs
+                   version = verstxt, stringsAsFactors = FALSE)
+  #df <- df[order(df$package, df$version, decreasing = TRUE), ]
+  newestinds <- findNewestRows(df)
+  df$newest <- FALSE
+  df$newest[newestinds] <- TRUE
+#  df <- df[order(df$package, df$version, decreasing = FALSE), ]
   old <- df[!df[, "newest"], ]
 
   # Create individual package archive dirs
@@ -46,3 +53,24 @@ updateArchive <- function (repo, repodest = destination(repo),
               file.path(archive, old$package, old$file))
   invisible(NULL)
 }
+
+.newestPkgVersion = function(inds, df) {
+    if(length(inds) ==1)
+        return(inds)
+    
+    curind = inds[1]
+    ## head(x, -1) is all but the last element
+    ## pass through the versions once to get the latest one
+    for(i in head(seq(along = inds), -1)) {
+        if(compareVersion(df$version[ inds[ i ] ],
+                          df$version[ inds[ i + 1 ] ]) < 0)
+            curind = inds[i+1]
+        }
+    curind
+}
+
+findNewestRows = function(df) {
+    indsbypkg = split(seq(along = df[[1]]), df$package)
+    res = lapply(indsbypkg, function(inds)  .newestPkgVersion(inds, df))
+    unlist(res)
+}
